const {override, fixBabelImports, getBabelLoader, addDecoratorsLegacy, disableEsLint} = require('customize-cra');

const fileLoaderMatcher = function (rule) {
    return rule.loader && rule.loader.indexOf(`file-loader`) !== -1;
};

function addPlugin(config) {
    config.module.rules[2].oneOf = [
        ...[
            /*-------------------------------------------ant design webpack config start-----------------------------------------------*/
            {
                test: /\.less$/,
                use: [
                    require.resolve('style-loader'),
                    require.resolve('css-loader'),
                    {
                        loader: require.resolve('postcss-loader'),
                        options: {
                            // Necessary for external CSS imports to work
                            // https://github.com/facebookincubator/create-react-app/issues/2677
                            ident: 'postcss',
                            plugins: () => [
                                require('postcss-flexbugs-fixes'),
                                require('postcss-preset-env')({
                                    autoprefixer: {
                                        flexbox: 'no-2009',
                                    },
                                    stage: 3,
                                }),
                            ],
                        },
                    },

                    // 此处可对ant design进行主题配置
                    {
                        loader: require.resolve('less-loader'),
                        options: {
                            javascriptEnabled: true,
                            // theme vars, also can use theme.js instead of this.
                            modifyVars: {
                                "@primary-color": "#719CF0",
                                "@menu-highlight-color": "#719CF0",
                                "@menu-item-active-bg": "rgba(13,156,240,.3)",
                                "@layout-header-background": "#1E4B9E",
                                "@layout-sider-background": "#fff",
                                "@btn-padding-sm": "0 4px - 1px"
                            },
                        },
                    },
                ]
            },
            /*-------------------------------------------ant design webpack config end-----------------------------------------------*/
        ],
        ...config.module.rules[2].oneOf
    ];


    // file-loader exclude
    let l = getBabelLoader(config, fileLoaderMatcher);
    let reg = /\.less$/;
    if (Array.isArray(l.exclude)) {
        l.exclude.push(reg);
    } else if (!!l.exclude) {
        l.exclude = [l.exclude, reg]
    } else {
        l.exclude = reg;
    }

    return config;
}

module.exports = override(
    addPlugin,
    fixBabelImports('import', { // 使用ant design的库
        libraryName: 'antd',
        style: true, // use less for customized theme
    }),
    addDecoratorsLegacy(), // 添加对装饰器的支持
    disableEsLint(),
);